import React from 'react';
import ReactDOM from 'react-dom';
import { arc } from 'd3';

const width = 1600; // Increased width to accommodate multiple cats
const height = 920; // Increased height for the same reason
const strokeWidth = 13;

const createCatAttributes = () => [
  {
    bodyColor: 'purple',
    eyeColor: 'green',
    posX: width / 4,
    posY: height / 4,
    sizeMultiplier: 1,
    earColor: 'orange',
  },
  {
    bodyColor: 'blue',
    eyeColor: 'yellow',
    posX: width / 2,
    posY: height / 4,
    sizeMultiplier: 0.8,
    earColor: 'pink',
  },
  {
    bodyColor: 'green',
    eyeColor: 'blue',
    posX: (3 * width) / 4,
    posY: height / 4,
    sizeMultiplier: 1.2,
    earColor: 'red',
  },
  {
    bodyColor: 'red',
    eyeColor: 'white',
    posX: width / 4,
    posY: (3 * height) / 4,
    sizeMultiplier: 0.6,
    earColor: 'yellow',
  },
  {
    bodyColor: 'yellow',
    eyeColor: 'black',
    posX: (3 * width) / 4,
    posY: (3 * height) / 4,
    sizeMultiplier: 1.4,
    earColor: 'green',
  },
];

const Cat = ({ attributes }) => {
  const {
    bodyColor,
    eyeColor,
    posX,
    posY,
    sizeMultiplier,
    earColor,
  } = attributes;
  const eyeOffsetX = 125 * sizeMultiplier;
  const eyeOffsetY = 50 * sizeMultiplier;
  const eyeRadius = 35 * sizeMultiplier;
  const mouthRadius = 20 * sizeMultiplier;
  const mouthWidth = 20 * sizeMultiplier;

  const mouthArc = arc()
    .innerRadius(mouthRadius)
    .outerRadius(mouthRadius + mouthWidth)
    .startAngle(Math.PI / 2)
    .endAngle((Math.PI * 3) / 2);

  const eyeArc = arc()
    .innerRadius(26 * sizeMultiplier)
    .outerRadius(40 * sizeMultiplier)
    .startAngle(-Math.PI / 3)
    .endAngle(Math.PI / 3);

  const earArc = arc()
    .innerRadius(40 * sizeMultiplier)
    .outerRadius(70 * sizeMultiplier)
    .startAngle(-Math.PI / 2)
    .endAngle(Math.PI / 2);

  return (
    <g transform={`translate(${posX},${posY})`}>
      <circle
        r={(height / 8) * sizeMultiplier}
        fill={bodyColor}
        stroke="black"
        strokeWidth={strokeWidth * sizeMultiplier}
      />
      {/* Eyes, ears, and mouth omitted for brevity, follow the same pattern as body for color and size */}
      <path
        d={mouthArc()}
        transform="translate(0,60)"
        fill="black"
      />
      <path
        d={eyeArc()}
        transform={`rotate(5) translate(-${eyeOffsetX},${-eyeOffsetY})`}
        fill={eyeColor}
      />
      <path
        d={eyeArc()}
        transform={`rotate(-5) translate(${eyeOffsetX},${-eyeOffsetY})`}
        fill={eyeColor}
      />
      <path
        d={earArc()}
        transform={`rotate(70) translate(0,${-height / 8 - 15 * sizeMultiplier})`}
        fill={earColor}
      />
      <path
        d={earArc()}
        transform={`rotate(-70) translate(0,${-height / 8 - 15 * sizeMultiplier})`}
        fill={earColor}
      />
    </g>
  );
};

const App = () => {
  const cats = createCatAttributes();
  return (
    <svg width={width} height={height}>
      {cats.map((attributes, index) => (
        <Cat key={index} attributes={attributes} />
      ))}
    </svg>
  );
};

const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
